@@ -2,6 +2,7 @@
 package Mail::Builder::Image::Data;
 # ============================================================================
 
+use namespace::autoclean;
 use Moose;
 extends qw(Mail::Builder::Image);
 
@@ -13,7 +14,6 @@ before BUILDARGS => sub{
     carp '<Mail::Builder::Image::Data> is deprecated, use <Mail::Builder::Image> instead';
 };
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
\ No newline at end of file
