@@ -30,9 +30,9 @@ has 'list' => (
 
 sub _check_list {
     my ($self,$value) = @_;
-    
+
     my $type = $self->type;
-    
+
     foreach my $element (@$value) {
         unless (blessed $element
             && $element->isa($type)) {
@@ -45,9 +45,9 @@ sub _check_list {
 around 'list' => sub {
     my $orig = shift;
     my $self = shift;
-    
+
     my $result = $self->$orig(@_);
-    
+
     return wantarray ? @{$result} : $result;
 };
 
@@ -66,14 +66,14 @@ around BUILDARGS => sub {
 
 __PACKAGE__->meta->make_immutable;
 
-sub _convert_item {
+sub _convert_item { ## no critic(RequireArgUnpacking)
     my ($self) = shift;
-    
+
     croak(qq[Params missing])
         unless scalar @_;
-    
+
     my $type = $self->type;
-    
+
     if (blessed($_[0])) {
         croak(qq[Invalid item added to list: Must be of $type])
             unless ($_[0]->isa($type));
@@ -84,26 +84,26 @@ sub _convert_item {
             unless (defined $object
             && blessed $object
             && $object->isa($type));
-        
+
         return $object;
     }
 }
 
 sub convert {
     my ($class,@elements) = @_;
-    
+
     my $elements_ref = (scalar @elements == 1 && ref $elements[0] eq 'ARRAY') ?
         $elements[0] : \@elements;
-    
+
     return $class->new(
         type    => ref($elements_ref->[0]),
         list    => $elements_ref,
     );
 }
 
-sub join {
+sub join { ## no critic(ProhibitBuiltinHomonyms)
     my ($self,$join_string) = @_;
-    
+
     return CORE::join $join_string,
         grep { $_ }
         map { $_->serialize }
@@ -112,10 +112,10 @@ sub join {
 
 sub contains {
     my ($self,$compare) = @_;
-    
+
     return 0
         unless (defined $compare);
-    
+
     foreach my $item ($self->list) {
         return 1
             if (blessed($compare) && $item == $compare);
@@ -125,24 +125,23 @@ sub contains {
     return 0;
 }
 
-sub reset {
+sub reset { ## no critic(ProhibitBuiltinHomonyms)
     my ($self) = @_;
-    
+
     $self->list([]);
-    
     return 1;
 }
 
-sub push {
+sub push { ## no critic(RequireArgUnpacking,ProhibitBuiltinHomonyms)
     my ($self) = @_;
     return $self->add(@_);
 }
 
 sub remove {
     my ($self,$remove) = @_;
-    
+
     my $list = $self->list;
-    
+
     # No params: take last param
     unless (defined $remove) {
         return pop @{$list};
@@ -162,7 +161,7 @@ sub remove {
             $index ++;
         }
         $self->list($new_list);
-        
+
         # Return old value
         return $remove
             if defined $remove;
@@ -170,30 +169,30 @@ sub remove {
     return;
 }
 
-sub add {
+sub add { ## no critic(RequireArgUnpacking)
     my ($self) = shift;
-    
+
     my $item = $self->_convert_item(@_);
-    
+
     unless ($self->contains($item)) {
         CORE::push(@{$self->list}, $item);
     }
-    
+
     return $item;
 }
 
 
 sub item {
     my ($self,$index) = @_;
-    
+
     $index = 0
         unless defined $index
         && $index =~ m/^\d+$/;
-    
-    return 
+
+    return
         unless ($index =~ m/^\d+$/
         && defined $self->list->[$index]);
-    
+
     return $self->list->[$index];
 }
 
